#!/usr/bin/perl -w

###
# Pod Documentation
###

=head1 NAME

fastq_to_fasta.pl

=head1 SYNOPSIS

Usage: fastq_to_fasta.pl input.fastq output.fasta

Convert a FASTQ formatted file to FASTA. Important: This script only 
works with FASTQ files where the sequence and qualities occupy only a 
single line each.

=head1 DESCRIPTION

=over

=back

=head1 AUTHOR

Jeffrey Barrick
<jbarrick@msu.edu>

=head1 COPYRIGHT

Copyright 2008.  All rights reserved.

=cut

###
# End Pod Documentation
###


use strict;
use Data::Dumper;

use FindBin;
use lib $FindBin::Bin;

use Bio::Location::Simple;
use Bio::DB::Flat;
use Bio::SeqIO;


#Get options
use Getopt::Long;
use Pod::Usage;
my ($help, $man);
my ($strip_names, $paired);
GetOptions(
	'help|?' => \$help, 'man' => \$man,
	'strip|s' => \$strip_names,
	'paired|p' => \$paired
) or pod2usage(2);
pod2usage(1) if $help;
pod2usage(-exitstatus => 0, -verbose => 2) if $man;

my ( $input, $output ) = @ARGV;


open INPUT, "<$input";
open OUTPUT, ">$output";

my $line = <INPUT>;

my $num_seq = 0;
my $num_per = 2;
my $remainder = 0;

my $index = 0;
while ($line)
{
	if ($strip_names)
	{
		$line =~ s/[^\/]+/$num_seq/;
		$line = ">" . $line;
	}
	else
	{
		$line =~ s/\@/>/;
	}
	
	print OUTPUT $line;
	$line = <INPUT>;
	print OUTPUT $line;
	$line = <INPUT>;
	$line = <INPUT>;
	$line = <INPUT>;

	if ($paired)
	{
		$remainder++;
		if ($remainder % $num_per == 0)
		{
			$num_seq++;
			$remainder = 0;
		}
	}
	else
	{
		$num_seq++;
	}
	
	#last if ($num_seq >= 1000000);
}

#Open Input/output
#
#my $in = Bio::SeqIO->new( -file => "<$input", -format => "fastq");
#my $out = Bio::SeqIO->new( -file => ">$output", -format => "fasta");
#
#my $seq = $in->next_seq;
#
#while ($seq)
#{
#	$seq = $in->next_seq;	
#	$out->write_seq($seq);
#}
